@@ -1,8 +1,9 @@
 from .base import AbstractBaseNode
-from .spatial import SpatialNodeMixin
 
 
-class LeafNode(AbstractBaseNode, SpatialNodeMixin):
+class LeafNode(AbstractBaseNode):
+
+    _type = 'LeafNode'
 
     @property
     def time(self):
@@ -13,7 +14,6 @@ class LeafNode(AbstractBaseNode, SpatialNodeMixin):
     def children(self):
         return tuple()
 
-    @property
     def as_scad(self, rendered):
         raise NotImplementedError(f"LeafNode subclass {self.__class__} must "
                                   "be able to output scad")
@@ -30,7 +30,7 @@ class LeafNode(AbstractBaseNode, SpatialNodeMixin):
 
         if not type(rendered).__module__.startswith(self.namespace):
             raise Exception(f"{self.__class__} is a LeafNode and should render "
-                            f"as {self.namespace} child, not {type(child)}")
+                            f"as {self.namespace} child, not {type(rendered)}")
 
     def collect_files(self):
         pass
